@@ -78,7 +78,7 @@ use Sys::Virt::NWFilter;
 use Sys::Virt::DomainSnapshot;
 use Sys::Virt::Stream;
 
-our $VERSION = '4.2.0';
+our $VERSION = '4.4.0';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -1763,6 +1763,17 @@ Only include features which can be live migrated.
 
 =back
 
+=item my $xml = $con->baseline_hypervisor_cpu($emulator, $arch, $machine, $virttype, \@xml, $flags=0)
+
+Given an array ref whose elements are XML documents describing host CPUs,
+compute the baseline CPU model that is operable across all hosts. The
+XML for the baseline CPU model is returned. Either C<$emulator> or C<$arch>
+must be a valid string referring to an emulator binary or an
+architecture name respectively. The C<$machine> parameter is
+an optional name of a guest machine, and C<$virttype> is an
+optional name of the virtualization type. The optional C<$flags>
+parameter accepts the same values as C<baseline_cpu>.
+
 =item @names = $con->get_cpu_model_names($arch, $flags=0)
 
 Get a list of valid CPU models names for the architecture
@@ -1809,6 +1820,18 @@ just returning a special error code.
 
 =back
 
+=item my $result = $con->compare_hypervisor_cpu($emulator, $arch, $machine, $virttype, $xml, $flags=0);
+
+Checks whether the CPU definition in C<$xml> is compatible with the
+current hypervisor connection. This can be used to determine whether
+it is safe to migrate a guest to this host. Either C<$emulator> or C<$arch>
+must be a valid string referring to an emulator binary or an
+architecture name respectively. The C<$machine> parameter is
+an optional name of a guest machine, and C<$virttype> is an
+optional name of the virtualization type. The returned result is
+one of the constants listed later The optional C<$flags> parameter
+can take the same values as the C<compare_cpu> method.
+
 =item $mem = $con->get_node_free_memory();
 
 Returns the current free memory on the host
