@@ -47,7 +47,7 @@ sub _new {
     my $class = ref($proto) || $proto;
     my %params = @_;
 
-    my $con = exists $params{connection} ? $params{connection} : die "connection parameter is requried";
+    my $con = exists $params{connection} ? $params{connection} : die "connection parameter is required";
     my $self;
     if (exists $params{name}) {
 	$self = Sys::Virt::NodeDevice::_lookup_by_name($con,  $params{name});
@@ -169,6 +169,18 @@ Include devices with the SCSI generic capability
 
 Include devices with the DRM capability
 
+=item Sys::Virt::NodeDevice::LIST_CAP_MDEV
+
+Include mediated devices
+
+=item Sys::Virt::NodeDevice::LIST_CAP_MDEV_TYPES
+
+Include devices capable of mediated devices
+
+=item Sys::Virt::NodeDevice::LIST_CAP_CCW_DEV
+
+Include CCW devices
+
 =back
 
 =head2 EVENT ID CONSTANTS
@@ -189,7 +201,7 @@ Node device config update events
 
 The following constants allow node device lifecycle change events to be
 interpreted. The events contain both a state change, and a
-reason though the reason is currently unsed.
+reason though the reason is currently unused.
 
 =over 4
 
